"use strict";

var _fs = _interopRequireDefault(require("fs"));

var _util = require("util");

var _stripBomBuf = _interopRequireDefault(require("strip-bom-buf"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const promisifiedFS = {};
const syncMethods = ['Stats', '_toUnixTimestamp', 'watch', 'watchFile', 'unwatchFile'];
Object.keys(_fs.default).forEach(function (key) {
  const value = _fs.default[key];

  if (typeof value === 'function' && !key.includes('Sync') && !key.includes('Stream') && !syncMethods.includes(key)) {
    promisifiedFS[key] = (0, _util.promisify)(value);
  } else {
    promisifiedFS[key] = value;
  }
});

promisifiedFS.exists = function (path) {
  return new Promise(function (resolve) {
    _fs.default.access(path, _fs.default.R_OK, function (error) {
      resolve(error === null);
    });
  });
};

promisifiedFS.readFile = function (path, encoding) {
  return new Promise(function (resolve, reject) {
    _fs.default.readFile(path, function (error, buffer) {
      if (error) {
        reject(error);
        return;
      }

      let contents = (0, _stripBomBuf.default)(buffer);

      if (encoding) {
        contents = contents.toString(encoding);
      }

      resolve(contents);
    });
  });
};

module.exports = promisifiedFS;